@@ -28,8 +28,27 @@ class Encoding():
         self.encodingnormal = {}
         for letter in Encodeable_letters:
             x = x + rate
-            self.encodingnormal[letter] = x
+            self.encodingnormal[letter] = str(x)
         self.encoding = TwoWayDict(self.encodingnormal)
+    
+    def encode(self,obj):
+        for character in obj:
+            encode = self.encoding[character]
+            if character == obj[-1]:
+                print(encode,end="\n")
+            else:
+                print(encode,end=" ")
+    
+    def decode(self,obj):
+        objspce = obj.count(" ") + 1
+        obj = obj.split(" ")
+        for r in range(objspce):
+            de = obj[r]
+            decode = self.encoding.reverse[de]
+            if de == obj[-1]:
+                print(decode,end="\n")
+            else:
+                print(decode,end="")
 class ListEncoding():
     def __init__(self,mix):
         self.encoding = []
@@ -42,7 +61,7 @@ class ListEncoding():
             charpos = self.encoding.index(character)
             ResultStr = str(self.encoding[-charpos  -self.mix])
             print(ResultStr,end='')
-class RandomEncoding():
+class RandomEncoding(Encoding):
     '''A way to generate a random encoding for your purposes. \n
     Encoding and decoding works the same as Encoding() \n
     Look at CreateAnEncoding.py and the Encoding() for an example of how to use it.
@@ -53,10 +72,8 @@ class RandomEncoding():
         self.encodingnormal = {}
         for letter in Encodeable_letters:
             x = x + self.rate
-            self.encodingnormal[letter] = x
+            self.encodingnormal[letter] = str(x)
         self.encoding = TwoWayDict(self.encodingnormal)
-x = TwoWayDict({'a':1})
-x.reverse[1]
 Gen2=[]
 GTX2 = []   
 ichorrev = {
